@@ -6,7 +6,7 @@ use ExtUtils::MakeMaker();
 use Carp;
 
 our @EXPORT = qw(WriteMakefile WriteInlineMakefile);
-our $VERSION = '0.79';
+our $VERSION = '0.80';
 
 sub WriteInlineMakefile {
     carp <<EOF;
@@ -96,12 +96,12 @@ MAKEFILE
     for (0..$#objects) {
         # the subdivision in hashes is done to avoid {}, which break dmake
         print MAKEFILE <<MAKEFILE;
-$obj_rules[$_]: \$(TO_INST_PM)
+$obj_rules[$_] : pm_to_blib
 \t\$(PERL) -Mblib -MInline=NOISY,_INSTALL_ -M$objects[$_] -e"my %A = (modinlname => '$obj_rules[$_]', module => '$objects[$_]'); my %S = (API => \\%A); Inline::satisfy_makefile_dep(\\%S);" $version \$(INST_ARCHLIB)
 MAKEFILE
     }
 
-print MAKEFILE "\npure_all :: ",join(' ',@obj_rules),"\n";
+print MAKEFILE "\ndynamic :: ",join(' ',@obj_rules),"\n";
 
 print MAKEFILE <<MAKEFILE;
 
